==> python-incidentio-client-0.9.1.tar.gz: python-incidentio-client-0.9.1/incident_io_client/api/utilities/utilities_open_api.py <==
from typing import Any, Dict, Optional

import httpx

from ...client import Client
from ...models.utilities_open_api_response_200 import UtilitiesOpenAPIResponse200
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
) -> Dict[str, Any]:
    url = f"{client.base_url}/v1/openapi.json"

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[UtilitiesOpenAPIResponse200]:
    if response.status_code == 200:
        response_200 = UtilitiesOpenAPIResponse200.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[UtilitiesOpenAPIResponse200]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
) -> Response[UtilitiesOpenAPIResponse200]:
    """OpenAPI Utilities

     Get the OpenAPI (v2) definition.

    Returns:
        Response[UtilitiesOpenAPIResponse200]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    response = httpx.get(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
) -> Optional[UtilitiesOpenAPIResponse200]:
    """OpenAPI Utilities

     Get the OpenAPI (v2) definition.

    Returns:
        Response[UtilitiesOpenAPIResponse200]
    """

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
) -> Response[UtilitiesOpenAPIResponse200]:
    """OpenAPI Utilities

     Get the OpenAPI (v2) definition.

    Returns:
        Response[UtilitiesOpenAPIResponse200]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
) -> Optional[UtilitiesOpenAPIResponse200]:
    """OpenAPI Utilities

     Get the OpenAPI (v2) definition.

    Returns:
        Response[UtilitiesOpenAPIResponse200]
    """

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed

==> python-incidentio-client-0.12.0.tar.gz: python-incidentio-client-0.12.0/incident_io_client/api/utilities/utilities_open_api.py <==
from typing import Any, Dict, Optional

import httpx

from ...client import Client
from ...models.utilities_open_api_response_200 import UtilitiesOpenAPIResponse200
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
) -> Dict[str, Any]:
    url = f"{client.base_url}/v1/openapi.json"

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[UtilitiesOpenAPIResponse200]:
    if response.status_code == 200:
        response_200 = UtilitiesOpenAPIResponse200.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[UtilitiesOpenAPIResponse200]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
) -> Response[UtilitiesOpenAPIResponse200]:
    """OpenAPI Utilities

     Get the OpenAPI (v2) definition.

    Returns:
        Response[UtilitiesOpenAPIResponse200]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
) -> Optional[UtilitiesOpenAPIResponse200]:
    """OpenAPI Utilities

     Get the OpenAPI (v2) definition.

    Returns:
        Response[UtilitiesOpenAPIResponse200]
    """

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
) -> Response[UtilitiesOpenAPIResponse200]:
    """OpenAPI Utilities

     Get the OpenAPI (v2) definition.

    Returns:
        Response[UtilitiesOpenAPIResponse200]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
) -> Optional[UtilitiesOpenAPIResponse200]:
    """OpenAPI Utilities

     Get the OpenAPI (v2) definition.

    Returns:
        Response[UtilitiesOpenAPIResponse200]
    """

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed
